//////////////////////////////////////////////////////////////////////////////////
//  Diffuse.vsh
//  Simple 3D model drawing vertex shader
//
//  Created by Bojan Endrovski on 23/09/2010.
//  Copyright Bojan Endrovski 2010. All rights reserved.
//////////////////////////////////////////////////////////////////////////////////

// Vertex atributes
attribute vec3 a_position;  // Position vertex attribute
attribute vec3 a_normal;    // Normal vertex attribute
attribute vec2 a_texture;   // Texture vertex attribute

// From vertex shader to fragment
// varying vec2 v_position;
varying vec2 v_texture;
varying vec3 v_color;

uniform mat4 u_worldviewproj;   // Premutiplied world-view-projection matrix
uniform mat3 u_normalmatrix;    // Matrix for transorming the normals
uniform vec3 u_lightdir;        // Light direction
uniform vec3 u_ambient;         // Ambient color


void main()
{
	// Expand position
    vec4 pos = u_worldviewproj * vec4(a_position, 1.0);
	gl_Position = pos;
    
    // Calculate normal
    vec3 normal = normalize(u_normalmatrix * a_normal);
    
    float intesity = max(0.0, dot(normal, u_lightdir));
    
    vec3 green = vec3(0.654902, 0.8, 0.639216);
    vec3 yellow = vec3(0.898039, 0.929412, 0.713725);
    
    v_color = mix(green, yellow, intesity);

    // just pass tex coordinates
    v_texture = a_texture;
}